package com.ruoyi.szxc.service.impl;

import com.ruoyi.szxc.domain.SzxcJmCar;
import com.ruoyi.szxc.mapper.SzxcJmCarMapper;
import com.ruoyi.szxc.service.ISzxcJmCarService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 居民车辆关联Service业务层处理
 *
 * @author hs
 * @date 2024-03-30
 */
@Service
public class SzxcJmCarServiceImpl implements ISzxcJmCarService
{
    @Autowired
    private SzxcJmCarMapper szxcJmCarMapper;

    /**
     * 查询居民车辆关联
     *
     * @param id 居民车辆关联主键
     * @return 居民车辆关联
     */
    @Override
    public SzxcJmCar selectSzxcJmCarById(Long id)
    {
        return szxcJmCarMapper.selectSzxcJmCarById(id);
    }

    /**
     * 查询居民车辆关联列表
     *
     * @param szxcJmCar 居民车辆关联
     * @return 居民车辆关联
     */
    @Override
    public List<SzxcJmCar> selectSzxcJmCarList(SzxcJmCar szxcJmCar)
    {
        return szxcJmCarMapper.selectSzxcJmCarList(szxcJmCar);
    }

    /**
     * 新增居民车辆关联
     *
     * @param szxcJmCar 居民车辆关联
     * @return 结果
     */
    @Override
    public int insertSzxcJmCar(SzxcJmCar szxcJmCar)
    {
        return szxcJmCarMapper.insertSzxcJmCar(szxcJmCar);
    }

    /**
     * 修改居民车辆关联
     *
     * @param szxcJmCar 居民车辆关联
     * @return 结果
     */
    @Override
    public int updateSzxcJmCar(SzxcJmCar szxcJmCar)
    {
        return szxcJmCarMapper.updateSzxcJmCar(szxcJmCar);
    }

    /**
     * 批量删除居民车辆关联
     *
     * @param ids 需要删除的居民车辆关联主键
     * @return 结果
     */
    @Override
    public int deleteSzxcJmCarByIds(Long[] ids)
    {
        return szxcJmCarMapper.deleteSzxcJmCarByIds(ids);
    }

    /**
     * 删除居民车辆关联信息
     *
     * @param id 居民车辆关联主键
     * @return 结果
     */
    @Override
    public int deleteSzxcJmCarById(Long id)
    {
        return szxcJmCarMapper.deleteSzxcJmCarById(id);
    }
}
